/* menus.c
 *
 * Copyright (C) 1999 Nick Yost
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

/* menus */

#include <config.h>
#include "menus.h"
#include "toolbar_pixmap.h"
#include "g3DGMVsrc.h"
#include "g3DGMVsig.h"


static void nothing_cb  (GtkWidget* widget, gpointer data);
static void close_cb    (GtkWidget* widget, gpointer data);
static void exit_cb     (GtkWidget* widget, gpointer data);
static void about_cb    (GtkWidget* widget, gpointer data);
static void propertybox (GtkWidget* widget, gpointer data);

static GnomeUIInfo file_menu [] = {
  GNOMEUIINFO_MENU_NEW_ITEM(N_("_New map"),
			    N_("Start a new project"),  
			    on_new_activate, NULL), 

  GNOMEUIINFO_MENU_OPEN_ITEM(on_File2_open_activate, NULL),

  GNOMEUIINFO_MENU_SAVE_ITEM(nothing_cb, NULL),

  GNOMEUIINFO_MENU_SAVE_AS_ITEM(on_File2_save_activate, NULL),

  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_MENU_CLOSE_ITEM(close_cb, NULL),

  GNOMEUIINFO_MENU_EXIT_ITEM(exit_cb, NULL),

  GNOMEUIINFO_END
};

static GnomeUIInfo edit_menu [] = {
  GNOMEUIINFO_MENU_CUT_ITEM(on_Edit_remove_activate, NULL), 
  GNOMEUIINFO_MENU_COPY_ITEM(on_Edit_copy_activate, NULL),
  GNOMEUIINFO_MENU_PASTE_ITEM(on_Edit_paste_activate, NULL),
  GNOMEUIINFO_MENU_SELECT_ALL_ITEM(nothing_cb, NULL), 
  GNOMEUIINFO_MENU_CLEAR_ITEM(on_Edit_delete_activate, NULL),
  GNOMEUIINFO_MENU_UNDO_ITEM(nothing_cb, NULL),
  GNOMEUIINFO_MENU_REDO_ITEM(nothing_cb, NULL), 
  GNOMEUIINFO_MENU_FIND_ITEM(nothing_cb, NULL), 
  GNOMEUIINFO_MENU_FIND_AGAIN_ITEM(nothing_cb, NULL), 
  GNOMEUIINFO_MENU_REPLACE_ITEM(nothing_cb, NULL),
  GNOMEUIINFO_MENU_PROPERTIES_ITEM(propertybox, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo help_menu [] = {
  //GNOMEUIINFO_HELP ("gnome-g3DGMV"),
  
  GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
  
  GNOMEUIINFO_END
};

static GnomeUIInfo menu [] = {
  GNOMEUIINFO_MENU_FILE_TREE(file_menu),
  GNOMEUIINFO_MENU_EDIT_TREE(edit_menu),
  GNOMEUIINFO_MENU_HELP_TREE(help_menu),
  GNOMEUIINFO_END
};

static GnomeUIInfo toolbar [] = {
  GNOMEUIINFO_ITEM_STOCK (N_("New"), N_("Start a new project"), on_new_activate, GNOME_STOCK_PIXMAP_NEW),

 
  GNOMEUIINFO_ITEM_STOCK (N_("File"), N_("Open a file"), on_File2_open_activate, GNOME_STOCK_PIXMAP_OPEN),


 GNOMEUIINFO_ITEM_STOCK (N_("Save"), N_("Save the current file"), on_File2_save_activate, GNOME_STOCK_PIXMAP_SAVE),

 GNOMEUIINFO_ITEM_STOCK (N_("Print"), N_("Print Map"), nothing_cb, GNOME_STOCK_PIXMAP_PRINT),

  GNOMEUIINFO_SEPARATOR,

  GNOMEUIINFO_ITEM_STOCK (N_("Copy"), N_("Copy the selection"),on_Edit_copy_activate , GNOME_STOCK_PIXMAP_COPY),
  GNOMEUIINFO_ITEM_STOCK (N_("Cut"), N_("Cut the selection"), on_Edit_remove_activate, GNOME_STOCK_PIXMAP_CUT),
  GNOMEUIINFO_ITEM_STOCK (N_("Paste"), N_("Paste the selection"), on_Edit_paste_activate, GNOME_STOCK_PIXMAP_PASTE),
  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_ITEM(N_("Tools"), N_("Drawing Tools"),on_Toolbox_activate,
		   draw_xpm),
  GNOMEUIINFO_ITEM(N_("Color"), N_("Select color"),on_colorBox_activate,
		   Scolor_xpm),

  GNOMEUIINFO_SEPARATOR,
  GNOMEUIINFO_ITEM_STOCK (N_("Exit"), N_("Exit the program"), exit_cb, GNOME_STOCK_PIXMAP_EXIT),

  GNOMEUIINFO_END
};



void 
install_menus_and_toolbar(GtkWidget* app)
{
 
  gnome_app_create_toolbar_with_data(GNOME_APP(app), toolbar, app);
  gnome_app_create_menus_with_data(GNOME_APP(app), menu, app);
  gnome_app_install_menu_hints(GNOME_APP(app), menu);
}

GtkWidget* 
get_menu_widget(gint i)
{
 return (menu[i].widget);
}

GtkWidget* 
get_menus_file_widget(gint i)
{
 return (file_menu[i].widget);
}

GtkWidget* 
get_toolbar_widget(gint i)
{
 return (toolbar[i].widget);
}

static void 
nothing_cb(GtkWidget* widget, gpointer data)
{
  GtkWidget* dialog;
  GtkWidget* app;
  
  app = (GtkWidget*) data;

  dialog = gnome_ok_dialog_parented(
          _("This feature has not yet been implemented"),
          GTK_WINDOW(app));
}

static void 
close_cb(GtkWidget* widget, gpointer data)
{
  GtkWidget* app;

  app = (GtkWidget*) data;

  Mapper_app_close(app);
}

static void 
exit_cb(GtkWidget* widget, gpointer data)
{
  gtk_main_quit();
}

static void 
about_cb(GtkWidget* widget, gpointer data)
{
  static GtkWidget* dialog = NULL;
  GtkWidget* app;

  app = (GtkWidget*) data;

  if (dialog != NULL) 
    {
      g_assert(GTK_WIDGET_REALIZED(dialog));
      gdk_window_show(dialog->window);
      gdk_window_raise(dialog->window);
    }
  else
    {        
      const gchar *authors[] = {
        "Nick Yost <yostn@linuxstart.com>",
        NULL
      };

      gchar* logo = gnome_pixmap_file("gnome-hello-logo.png");

      dialog = gnome_about_new (_("g3DGMV"), VERSION,
                                "(C) 1999 Nick Yost",
                                authors,
                                _("The g3DGMV program was design as a viewer for Digital Elevation Model(DEM) and Digital Line Graphs (DLG)"),
                                logo);

      g_free(logo);

      gtk_signal_connect(GTK_OBJECT(dialog),
                         "destroy",
                         GTK_SIGNAL_FUNC(gtk_widget_destroyed),
                         &dialog);

      gnome_dialog_set_parent(GNOME_DIALOG(dialog), GTK_WINDOW(app));

      gtk_widget_show(dialog);
    }
}

void enable_background(GtkWidget *widget, gpointer data )
{
  ElevMap *Map = getmap();
  GtkWidget *  gnome_property_box;
  gnome_property_box = get_widget ((GtkWidget *) data, "gnome_property_box");

  if (GTK_TOGGLE_BUTTON (widget)->active)
    Map->bk_enable=TRUE;
  else
    Map->bk_enable=FALSE;
      
  gnome_property_box_changed((GnomePropertyBox *) gnome_property_box);
}

void disable_background(GtkWidget *widget, gpointer data )
{
  ElevMap *Map = getmap();
  GtkWidget *  gnome_property_box;
  gnome_property_box = get_widget ((GtkWidget *) data, "gnome_property_box");

  if (GTK_TOGGLE_BUTTON (widget)->active)
    Map->bk_enable=FALSE;
  else
    Map->bk_enable=TRUE;
      
  gnome_property_box_changed((GnomePropertyBox *) gnome_property_box);
}

void handler(GtkWidget *propertybox, int page_number, gpointer data )
{
   ElevMap *Map = getmap();
   if (page_number == 0 && Map->col_list_ptr != NULL)
     Generate_DEM(data,0,0,0,0,TRUE);
}



/* Redraw the background thumbnail */
static gint
bgt_expose_event                           (GtkWidget    *pdrawingarea,
                                        GdkEventExpose     *event)
{
  GdkDrawable *pixmap;
  ElevMap *Map = getmap();  
  
  
   if(Map->background !=NULL){
     gdk_imlib_render(Map->background,pdrawingarea->allocation.width,
		       pdrawingarea->allocation.height);  
     pixmap = gdk_imlib_move_image(Map->background);
     gdk_draw_pixmap    (pdrawingarea->window,
			 pdrawingarea->style->white_gc,
			 pixmap,
			 0,0,
			 0,0,
			 pdrawingarea->allocation.width,
			 pdrawingarea->allocation.height);}
  return FALSE;
}

 
GtkWidget* create_backgroundbox(GtkWidget* widget, gpointer data)
{
   GtkWidget* app;
   GtkWidget *pfixed1;
   GtkWidget * Choose_button1;
   GSList *pfixed1_group = NULL;
   GtkWidget *pradiobutton1;
   GtkWidget *pradiobutton2;
   GtkWidget *pviewport1;
   GtkWidget *pdrawingarea;
   static GtkWidget *pentry1;
   GtkWidget *hseparator1;
   
  
   app = (GtkWidget*) data;

   pfixed1 = gtk_fixed_new ();
   gtk_object_set_data (GTK_OBJECT (app), "pfixed1", pfixed1);
   gtk_widget_show (pfixed1);

   Choose_button1 = gtk_button_new_with_label ("Choose File");
   gtk_object_set_data (GTK_OBJECT (app), " Choose_button1", Choose_button1);
   gtk_widget_show ( Choose_button1);
   gtk_fixed_put (GTK_FIXED (pfixed1),  Choose_button1, 229, 32);
   gtk_widget_set_usize (Choose_button1, 80, 24);

   gtk_signal_connect (GTK_OBJECT (Choose_button1), "clicked",
		       GTK_SIGNAL_FUNC (on_File_open_background_activate), 
		       (gpointer) app); 

   pradiobutton1 = gtk_radio_button_new_with_label (pfixed1_group,
						   "BackGround Enabled");
   pfixed1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (pradiobutton1));
   gtk_object_set_data (GTK_OBJECT (app), "pradiobutton1", pradiobutton1);
   gtk_widget_show (pradiobutton1);
   gtk_fixed_put (GTK_FIXED (pfixed1), pradiobutton1, 24, 96);
   gtk_widget_set_usize (pradiobutton1, 168, 32);
   gtk_signal_connect (GTK_OBJECT (pradiobutton1), "clicked",
		       GTK_SIGNAL_FUNC (enable_background), 
		       (gpointer) app); 

   pradiobutton2 = gtk_radio_button_new_with_label (pfixed1_group, 
						   "BackGround Disabled");
   pfixed1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (pradiobutton2));
   gtk_object_set_data (GTK_OBJECT (app), "pradiobutton2", pradiobutton2);
   gtk_widget_show (pradiobutton2);
   gtk_fixed_put (GTK_FIXED (pfixed1), pradiobutton2, 24, 128);
   gtk_widget_set_usize (pradiobutton2, 160, 32);
   gtk_signal_connect (GTK_OBJECT (pradiobutton2), "clicked",
		       GTK_SIGNAL_FUNC (disable_background), 
		       (gpointer) app); 

   pviewport1 = gtk_viewport_new (NULL, NULL);
   gtk_object_set_data (GTK_OBJECT (app), "pviewport1", pviewport1);
   gtk_widget_show (pviewport1);
   gtk_fixed_put (GTK_FIXED (pfixed1), pviewport1, 360, 31);
   gtk_widget_set_usize (pviewport1, 96, 96);

   pdrawingarea = gtk_drawing_area_new ();
   gtk_object_set_data (GTK_OBJECT (app), "pdrawingarea", pdrawingarea);
   gtk_widget_show (pdrawingarea);
   gtk_container_add (GTK_CONTAINER (pviewport1), pdrawingarea);

  
   pentry1 = gtk_entry_new ();
   gtk_object_set_data (GTK_OBJECT (app), "pentry1", pentry1);
   gtk_widget_show (pentry1);
   gtk_fixed_put (GTK_FIXED (pfixed1), pentry1, 8, 32);
   gtk_widget_set_usize (pentry1, 208, 24);

   hseparator1 = gtk_hseparator_new ();
   gtk_object_set_data (GTK_OBJECT (app), "hseparator1", hseparator1);
   gtk_widget_show (hseparator1);
   gtk_fixed_put (GTK_FIXED (pfixed1), hseparator1, 8, 64);
   gtk_widget_set_usize (hseparator1, 296, 32);

   /* Signals used to Redraw the background thumbnail */
   gtk_signal_connect(GTK_OBJECT(pdrawingarea), "expose_event",
		      (GtkSignalFunc) bgt_expose_event,
		      NULL);
 
  gtk_widget_set_events (pdrawingarea, GDK_EXPOSURE_MASK);
	
   
   

   return pfixed1;
  
}

static void 
propertybox(GtkWidget* widget, gpointer data)
{
   GtkWidget* app;
   GtkWidget* gnome_property_box;
   GtkWidget* lbk1;
   GtkWidget *backgroundbox;
   GtkWidget *pdrawingarea;
   GtkWidget *entry;
   GdkDrawable *pixmap;
   ElevMap *Map = getmap();

   app = (GtkWidget*) data;
  

   gnome_property_box=gnome_property_box_new();
   gtk_object_set_data (GTK_OBJECT (app), "gnome_property_box", 
			gnome_property_box); 
   

   backgroundbox = create_backgroundbox(widget,data);
   

   lbk1 = gtk_label_new("background");
   gtk_widget_show(lbk1);

   gnome_property_box_append_page((GnomePropertyBox*)gnome_property_box,
				  backgroundbox,lbk1);
  

   gtk_signal_connect (GTK_OBJECT (gnome_property_box), "apply",
		       GTK_SIGNAL_FUNC (handler), 
		       (gpointer) app);
  
   gtk_widget_show(gnome_property_box);
   gtk_grab_add(gnome_property_box);
   gtk_window_set_transient_for( GTK_WINDOW(gnome_property_box),
				 GTK_WINDOW (app));


   while (gtk_events_pending())
	  gtk_main_iteration();

   /* redraw background thumbnail image */
   pdrawingarea = get_widget ((GtkWidget *) app, "pdrawingarea");
   entry = get_widget ((GtkWidget *) app, "pentry1");

   gtk_entry_set_text((GtkEntry *) entry,Map->bg_str);

   if(Map->background !=NULL){
     gdk_imlib_render(Map->background,pdrawingarea->allocation.width,
		       pdrawingarea->allocation.height);  
     pixmap = gdk_imlib_move_image(Map->background);
     gdk_draw_pixmap    (pdrawingarea->window,
			 pdrawingarea->style->white_gc,
			 pixmap,
			 0,0,
			 0,0,
			 pdrawingarea->allocation.width,
			 pdrawingarea->allocation.height);}

  
}

/*** menus ***/
